| Title: | Find the Location of an R Package's Code |
|---|---|
| Description: | Find the location of the code for an R package based on the package's name or string representation. Checks on CRAN based on information in the URL field or BioConductor and GitHub based on constructing a URL, and verifies all paths via testing for a successful response. This can be useful when automating static code analysis based on a list of package names, and similar tasks. |
| Authors: | Nic Crane [aut, cre, cph] |
| Maintainer: | Nic Crane <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1.9000 |
| Built: | 2026-05-11 09:34:31 UTC |
| Source: | https://github.com/thisisnic/codewhere |
Find a package's code
code_where(package_name, package_type = "cran")code_where(package_name, package_type = "cran")
package_name |
The name of the package |
package_type |
One of "cran", "bioc", or "github" |
Path to where code can be found or NULL
code_where("dplyr")code_where("dplyr")