Welcome to ClientVPS Mirrors

Help for package codewhere
Type: Package
Title: Find the Location of an R Package's Code
Version: 0.1.1
Description: Find the location of the code for an R package based on the package's name or string representation. Checks on 'CRAN' based on information in the 'URL' field or 'BioConductor' and 'GitHub' based on constructing a URL, and verifies all paths via testing for a successful response. This can be useful when automating static code analysis based on a list of package names, and similar tasks.
License: MIT + file LICENSE
URL: https://thisisnic.github.io/codewhere/, https://github.com/thisisnic/codewhere/
BugReports: https://github.com/thisisnic/codewhere/issues
Encoding: UTF-8
Imports: httr
Suggests: httptest, testthat (≥ 3.0.0)
Config/testthat/edition: 3
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-06-01 08:59:44 UTC; nic
Author: Nic Crane [aut, cre, cph]
Maintainer: Nic Crane <thisisnic@gmail.com>
Repository: CRAN
Date/Publication: 2024-06-04 09:47:09 UTC

Find a package's code

Description

Find a package's code

Usage

code_where(package_name, package_type = "cran")

Arguments

package_name

The name of the package

package_type

One of "cran", "bioc", or "github"

Value

Path to where code can be found or NULL

Examples

code_where("dplyr")

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.